Structs

Constants

Functions

  • | Shuffle and select coins until nTargetValue | is reached while avoiding small change; | This method is stochastic for some inputs | and upon completion the coin set and | corresponding actual target value | is assembled | | ———– | @param[in] coins | | Set of UTXOs to consider. These will | be categorized into | | OutputGroups and filtered using eligibility_filter | before selecting coins. | ––––– | @param[out] setCoinsRet | | Populated with the coins selected if | successful. | ––––– | @param[out] nValueRet | | Used to return the total value of selected | coins. |
  • | populate vCoins with vector of available | COutputs. |
  • | Get the marginal bytes of spending the | specified output |
  • | Calculate the size of the transaction | assuming all signatures are max size | | Use DummySignatureCreator, which | inserts 71 byte signatures everywhere. | | ———– | @note | | this requires that all inputs must be | in mapWallet (eg the tx should be AllInputsMine). | | txouts needs to be in the order of tx.vin |
  • | Create a new transaction paying the | recipients with a set of coins selected | by SelectCoins(); Also create the change | output, when needed | | ———– | @note | | passing nChangePosInOut as -1 will | result in setting a random position |
  • | Find non-change parent output. |
  • | Insert additional inputs into the transaction | by calling CreateTransaction(); |
  • | Return a height-based locktime for | new transactions (uses the height of | the current chain tip unless we are not | synced with the current chain |
  • | Get the marginal bytes if spending the | specified output from this transaction |
  • | Return list of available coins and locked | coins grouped by non-change output | address. |
  • | Select a set of coins such that nValueRet | >= nTargetValue and at least all coins | from coin_control are selected; never | select unconfirmed coins if they are | not ours | | ———– | @param[out] setCoinsRet | | Populated with inputs including pre-selected | inputs from coin_control and Coin Selection | if successful. | ––––– | @param[out] nValueRet | | Total value of selected coins including | pre-selected ones from coin_control | and Coin Selection if successful. |